@@ -1,6 +1,6 @@
-from django.urls import include, path
 from django.conf.urls.i18n import i18n_patterns
 from django.contrib import admin
+from django.urls import include, path
 
 admin.autodiscover()
 
@@ -8,6 +8,6 @@ admin.autodiscover()
 # This is not mandatory, can also use a `django_language` cookie,
 # or custom middleware that calls `django.utils.translation.activate()`.
 urlpatterns = i18n_patterns(
-    path('admin/', admin.site.urls),
-    path('', include('article.urls')),
+    path("admin/", admin.site.urls),
+    path("", include("article.urls")),
 )
