@@ -1,6 +1,7 @@
 from django.core.cache import cache
-from .utils import AppTestCase
+
 from .testapp.models import Level2
+from .utils import AppTestCase
 
 
 class ModelInheritanceTests(AppTestCase):
@@ -12,12 +13,12 @@ class ModelInheritanceTests(AppTestCase):
         """
         Test whether passing translated attributes to __init__() works.
         """
-        x = Level2(l1_title='LEVEL1', l2_title='LEVEL2', id=1)
+        x = Level2(l1_title="LEVEL1", l2_title="LEVEL2", id=1)
         self.assertEqual(x.l1_title, "LEVEL1")
         self.assertEqual(x.l2_title, "LEVEL2")
 
     def test_save_two_levels(self):
-        x = Level2(l1_title='LEVEL1', l2_title='LEVEL2', id=2)
+        x = Level2(l1_title="LEVEL1", l2_title="LEVEL2", id=2)
         x.save()
         cache.clear()
 
@@ -31,9 +32,9 @@ class ModelInheritanceTests(AppTestCase):
         self.assertEqual(translation.l2_title, "LEVEL2")
 
     def test_prefetch_levels(self):
-        x = Level2(l1_title='LEVEL1', l2_title='LEVEL2', id=3)
+        x = Level2(l1_title="LEVEL1", l2_title="LEVEL2", id=3)
         x.save()
 
-        x = Level2.objects.prefetch_related('l1_translations').get(pk=x.pk)
+        x = Level2.objects.prefetch_related("l1_translations").get(pk=x.pk)
         self.assertEqual(x.l1_title, "LEVEL1")
         self.assertEqual(x.l2_title, "LEVEL2")
